@@ -1,6 +1,6 @@
 package Role::REST::Client;
 {
-  $Role::REST::Client::VERSION = '0.10';
+  $Role::REST::Client::VERSION = '0.11';
 }
 
 use Moose::Role;
@@ -54,11 +54,13 @@ has 'persistent_headers' => (
 	},
 );
 has 'httpheaders' => (
-	traits    => ['Hash'],
-	is        => 'rw',
-	isa       => 'HashRef[Str]',
-	default   => sub { {} },
-	handles   => {
+	traits      => ['Hash'],
+	is          => 'ro',
+	isa         => 'HashRef[Str]',
+	writer      => '_set_httpheaders',
+	builder     => '_build_httpheaders',
+	initializer => '_build_httpheaders',
+	handles     => {
 		set_header     => 'set',
 		get_header     => 'get',
 		has_no_headers => 'is_empty',
@@ -73,6 +75,14 @@ has serializer_class => (
 
 no Moose::Util::TypeConstraints;
 
+sub _build_httpheaders {
+	my ($self, $headers) = @_;
+	$headers ||= {};
+	$self->_set_httpheaders( { %{$self->persistent_headers}, %$headers });
+}
+
+sub reset_headers {my $self = shift;$self->_set_httpheaders($self->persistent_headers)}
+
 sub _rest_response_class { 'Role::REST::Client::Response' }
 
 sub _handle_response {
@@ -133,7 +143,7 @@ sub _call {
 		$options{'headers'}{'content-length'} = length($options{'content'});
 	}
 	my $res = $self->_handle_response( $self->do_request($method, $uri, \%options) );
-	$self->httpheaders($self->persistent_headers) unless $args->{preserve_headers};
+	$self->reset_headers unless $args->{preserve_headers};
 	# Return an error if status 5XX
 	return $self->_new_rest_response(
 		code => $res->code,
@@ -204,7 +214,7 @@ Role::REST::Client - REST Client Role
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
